# -*- coding: utf-8 -*
from bw2data import *
from bw2calc import *
from bw2io import *

__version__ = (2, 4, 1)
